@@ -236,7 +236,4 @@ class DescribeOperation:
             )
         )
 
-        if is_bigquery(percentile_df.engine):
-            # BigQuery returns quantile per row, need to apply distinct
-            percentile_df = percentile_df.materialize(node_name='describe_quantile', distinct=True)
         return percentile_df
